@@ -1,12 +1,10 @@
 /* SPDX-License-Identifier: LGPL-2.1-only */
 
-#include "nl-default.h"
-
+#include <netlink-private/netlink.h>
+#include <netlink-private/types.h>
+#include <netlink-private/route/nexthop-encap.h>
 #include <linux/lwtunnel.h>
 
-#include "nl-route.h"
-#include "nexthop-encap.h"
-
 static struct lwtunnel_encap_type {
 	const char *name;
 	struct nh_encap_ops *ops;
@@ -33,13 +31,10 @@ static const char *nh_encap_type2str(unsigned int type)
 
 void nh_encap_dump(struct rtnl_nh_encap *rtnh_encap, struct nl_dump_params *dp)
 {
-	if (!rtnh_encap->ops)
-		return;
-
 	nl_dump(dp, " encap %s ",
 		nh_encap_type2str(rtnh_encap->ops->encap_type));
 
-	if (rtnh_encap->ops->dump)
+	if (rtnh_encap->ops && rtnh_encap->ops->dump)
 		rtnh_encap->ops->dump(rtnh_encap->priv, dp);
 }
 
