@@ -18,20 +18,15 @@
  * ~~~~
  */
 
-#include "nl-default.h"
-
-#include <locale.h>
-
-#include <linux/socket.h>
-#include <linux/if_arp.h>
-
+#include <netlink-private/netlink.h>
+#include <netlink-private/utils.h>
 #include <netlink/netlink.h>
 #include <netlink/utils.h>
-
-#include "nl-core.h"
-#include "nl-priv-dynamic-core/object-api.h"
-#include "nl-priv-dynamic-core/nl-core.h"
-#include "nl-aux-core/nl-core.h"
+#include <linux/socket.h>
+#include <stdlib.h> /* exit() */
+#ifdef HAVE_STRERROR_L
+#include <locale.h>
+#endif
 
 /**
  * Global variable indicating the desired level of debugging output.
@@ -52,15 +47,16 @@
 int nl_debug = 0;
 
 /** @cond SKIP */
+#ifdef NL_DEBUG
 struct nl_dump_params nl_debug_dp = {
 	.dp_type = NL_DUMP_DETAILS,
 };
 
-static void _nl_init nl_debug_init(void)
+static void __init nl_debug_init(void)
 {
 	char *nldbg, *end;
 
-	if (NL_DEBUG && (nldbg = getenv("NLDBG"))) {
+	if ((nldbg = getenv("NLDBG"))) {
 		long level = strtol(nldbg, &end, 0);
 		if (nldbg != end)
 			nl_debug = level;
@@ -68,6 +64,7 @@ static void _nl_init nl_debug_init(void)
 
 	nl_debug_dp.dp_fd = stderr;
 }
+#endif
 
 int __nl_read_num_str_file(const char *path, int (*cb)(long, const char *))
 {
@@ -120,63 +117,6 @@ int __nl_read_num_str_file(const char *path, int (*cb)(long, const char *))
 	return 0;
 }
 
-struct trans_list {
-	int i;
-	char *a;
-	struct nl_list_head list;
-};
-
-int nl_getprotobyname(const char *name)
-{
-	const struct protoent *result;
-
-#if HAVE_DECL_GETPROTOBYNAME_R
-	struct protoent result_buf;
-	char buf[2048];
-	int r;
-
-	r = getprotobyname_r(name, &result_buf, buf, sizeof(buf),
-			     (struct protoent **)&result);
-	if (r != 0 || result != &result_buf)
-		result = NULL;
-#else
-	result = getprotobyname(name);
-#endif
-
-	if (!result)
-		return -1;
-
-	if (result->p_proto < 0 || result->p_proto > UINT8_MAX)
-		return -1;
-	return (uint8_t)result->p_proto;
-}
-
-bool nl_getprotobynumber(int proto, char *out_name, size_t name_len)
-{
-	const struct protoent *result;
-
-#if HAVE_DECL_GETPROTOBYNUMBER_R
-	struct protoent result_buf;
-	char buf[2048];
-	int r;
-
-	r = getprotobynumber_r(proto, &result_buf, buf, sizeof(buf),
-			       (struct protoent **)&result);
-	if (r != 0 || result != &result_buf)
-		result = NULL;
-#else
-	result = getprotobynumber(proto);
-#endif
-
-	if (!result)
-		return false;
-
-	if (strlen(result->p_name) >= name_len)
-		return false;
-	strcpy(out_name, result->p_name);
-	return true;
-}
-
 const char *nl_strerror_l(int err)
 {
 	const char *buf;
@@ -919,8 +859,12 @@ int nl_str2ether_proto(const char *name)
 
 char *nl_ip_proto2str(int proto, char *buf, size_t len)
 {
-	if (nl_getprotobynumber(proto, buf, len))
+	struct protoent *p = getprotobynumber(proto);
+
+	if (p) {
+		snprintf(buf, len, "%s", p->p_name);
 		return buf;
+	}
 
 	snprintf(buf, len, "0x%x", proto);
 	return buf;
@@ -928,19 +872,15 @@ char *nl_ip_proto2str(int proto, char *buf, size_t len)
 
 int nl_str2ip_proto(const char *name)
 {
+	struct protoent *p = getprotobyname(name);
 	unsigned long l;
 	char *end;
-	int p;
 
-	if (!name)
-		return -NLE_INVAL;
-
-	p = nl_getprotobyname(name);
-	if (p >= 0)
-		return p;
+	if (p)
+		return p->p_proto;
 
 	l = strtoul(name, &end, 0);
-	if (name == end || *end != '\0' || l > (unsigned long)INT_MAX)
+	if (l == ULONG_MAX || *end != '\0')
 		return -NLE_OBJ_NOTFOUND;
 
 	return (int) l;
@@ -1069,15 +1009,14 @@ char *__type2str(int type, char *buf, size_t len,
 		 const struct trans_tbl *tbl, size_t tbl_len)
 {
 	size_t i;
-
 	for (i = 0; i < tbl_len; i++) {
-		if (tbl[i].i == ((uint64_t)type)) {
+		if (tbl[i].i == type) {
 			snprintf(buf, len, "%s", tbl[i].a);
 			return buf;
 		}
 	}
 
-	snprintf(buf, len, "0x%x", (unsigned)type);
+	snprintf(buf, len, "0x%x", type);
 	return buf;
 }
 
@@ -1170,7 +1109,7 @@ int __str2flags(const char *buf, const struct trans_tbl *tbl, size_t tbl_len)
 			p++;
 
 		t = strchr(p, ',');
-		len = t ? ((size_t)(t - p)) : strlen(p);
+		len = t ? t - p : strlen(p);
 		for (i = 0; i < tbl_len; i++)
 			if (len == strlen(tbl[i].a) &&
 			    !strncasecmp(tbl[i].a, p, len))
@@ -1280,24 +1219,6 @@ int nl_has_capability (int capability)
 			NL_CAPABILITY_VERSION_3_5_0,
 			NL_CAPABILITY_NL_OBJECT_IDENTICAL_PARTIAL,
 			NL_CAPABILITY_VERSION_3_6_0),
-		_NL_SET (4,
-			NL_CAPABILITY_VERSION_3_7_0,
-			NL_CAPABILITY_VERSION_3_8_0,
-			NL_CAPABILITY_VERSION_3_9_0,
-			NL_CAPABILITY_VERSION_3_10_0,
-			NL_CAPABILITY_VERSION_3_11_0,
-			NL_CAPABILITY_VERSION_3_12_0,
-			0, /* NL_CAPABILITY_VERSION_3_13_0 */
-			0), /* NL_CAPABILITY_VERSION_3_14_0 */
-		_NL_SET (5,
-			NL_CAPABILITY_ROUTE_FIX_PARSE_BONDING,
-			0, /* NL_CAPABILITY_VERSION_3_15_0 */
-			0,
-			0,
-			0,
-			0,
-			0,
-			0),
 		/* IMPORTANT: these capability numbers are intended to be universal and stable
 		 * for libnl3. Don't allocate new numbers on your own that differ from upstream
 		 * libnl3.
