@@ -1,21 +1,15 @@
-/* SPDX-License-Identifier: LGPL-2.1-only */
-
-#include "nl-default.h"
-
+#include <linux/netlink.h>
 #include <stdio.h>
 #include <time.h>
 #include <check.h>
 
-#include <linux/netlink.h>
-
-#include <netlink/route/cls/ematch.h>
-
+#include "netlink-private/types.h"
+#include "netlink/route/cls/ematch.h"
 #include "cksuite-all.h"
-#include "nl-aux-route/nl-route.h"
-#include "nl-priv-dynamic-route/nl-priv-dynamic-route.h"
+#include "netlink-private/nl-auto.h"
 
-#define MAX_DEPTH 6
-#define MAX_CHILDREN 5
+#define MAX_DEPTH		6
+#define MAX_CHILDREN		5
 
 static int current_depth = 0;
 static int id = 1;
@@ -31,13 +25,19 @@ static long long my_pow(long long x, long long y)
 	if (y < 0 || x == 0)
 		return 0;
 
-	while (--y) {
+	while(--y) {
 		ret *= x;
 	}
 
 	return ret;
 }
 
+static long int generate_random(long int max)
+{
+	srandom(time(NULL) + id);
+	return (random() % max);
+}
+
 static int build_children(struct nl_list_head *parent)
 {
 	int i, num = 0;
@@ -51,7 +51,7 @@ static int build_children(struct nl_list_head *parent)
 		return 0;
 	}
 
-	num = _nltst_rand_u32() % ((unsigned)(MAX_CHILDREN + 1));
+	num = generate_random(MAX_CHILDREN + 1);
 	for (i = 0; i < num; ++i) {
 		child = rtnl_ematch_alloc();
 		if (!child) {
@@ -84,8 +84,7 @@ static void dump_ematch_list(struct nl_list_head *head, int *result, int *index)
 	}
 }
 
-static void dump_ematch_tree(struct rtnl_ematch_tree *tree, int *result,
-			     int *index)
+static void dump_ematch_tree(struct rtnl_ematch_tree *tree, int *result, int *index)
 {
 	if (!tree)
 		return;
